__all__ = [
    'ADJECTIVES',
    'ANIMALS',
]

ADJECTIVES = [
    'adorable',
    'acrobatic',
    'adaptable',
    'adventurous',
    'agile',
    'alert',
    'amiable',
    'amused',
    'arboreal',
    'ardent',
    'artful',
    'astonishing',
    'astute',
    'attentive',
    'authentic',
    'avid',
    'beardless',
    'benevolent',
    'bicameral',
    'big',
    'bionic',
    'blissful',
    'bodacious',
    'brave',
    'bright',
    'brilliant',
    'bubbly',
    'careful',
    'cautious',
    'cavernous',
    'charming',
    'cheeky',
    'cheerful',
    'circumspect',
    'cognizant',
    'cool',
    'collaborative',
    'collectible',
    'colorful',
    'colossal',
    'comfortable',
    'communicative',
    'compact',
    'compassionate',
    'constant',
    'contemplative',
    'contiguous',
    'convincing',
    'convivial',
    'cooperative',
    'courageous',
    'cordial',
    'cosmic',
    'creative',
    'cryptic',
    'crystalline',
    'cunning',
    'curious',
    'dancing',
    'daring',
    'dauntless',
    'dashing',
    'dazzling',
    'defiant',
    'delightful',
    'determined',
    'dexterous',
    'diminutive',
    'discerning',
    'distinctive',
    'dreaming',
    'dynamic',
    'eager',
    'earnest',
    'easygoing',
    'ebullient',
    'eccentric',
    'ecstatic',
    'effluvial',
    'effervescent',
    'elaborate',
    'elated',
    'elegant',
    'eloquent',
    'elusive',
    'enchanting',
    'encouraging',
    'energetic',
    'energized',
    'enormous',
    'enthusiastic',
    'erudite',
    'essential',
    'ethereal',
    'excited',
    'exhilarated',
    'extraordinary',
    'exotic',
    'exuberant',
    'fantastic',
    'fearless',
    'feisty',
    'fierce',
    'fiery',
    'flourishing',
    'flying',
    'focused',
    'fortunate',
    'friendly',
    'frolicking',
    'gargantuan',
    'gesticulating',
    'gigantic',
    'glamorous',
    'gleaming',
    'gleeful',
    'glorious',
    'gorgeous',
    'graceful',
    'grateful',
    'gregarious',
    'happy',
    'harmonious',
    'hatless',
    'healthy',
    'helpful',
    'heroic',
    'hydraulic',
    'hyena',
    'idealistic',
    'illustrious',
    'illustrative',
    'imaginative',
    'immense',
    'impartial',
    'imperturbable',
    'improbable',
    'incredible',
    'inimitable',
    'influential',
    'inquisitive',
    'insightful',
    'inspired',
    'intrepid',
    'intricate',
    'intuitive',
    'invaluable',
    'inventive',
    'iterative',
    'jaunty',
    'jolly',
    'joyful',
    'joyous',
    'jubilant',
    'jumping',
    'katabatic',
    'keen',
    'kempt',
    'kept',
    'kind',
    'kindled',
    'kinematic',
    'kinesthtic',
    'kingly',
    'kitschy',
    'knightly',
    'knowing',
    'kooky',
    'kyphotic',
    'large',
    'laughing',
    'legendary',
    'lenient',
    'lively',
    'loquacious',
    'lucky',
    'luminescent',
    'magnetic',
    'magnificent',
    'majestic',
    'marvelous',
    'masked',
    'massive',
    'mechanical',
    'mercurial',
    'meritorious',
    'merry',
    'methodical',
    'meticulous',
    'mighty',
    'miniature',
    'mirthful',
    'mischievous',
    'modest',
    'momentous',
    'motionless',
    'multicolored',
    'murmuring',
    'musical',
    'mustachioed',
    'mysterious',
    'nascent',
    'neighborly',
    'noble',
    'nomadic',
    'nonchalant',
    'noncommittal',
    'observant',
    'omnidirectional',
    'omnipotent',
    'omnipresent',
    'omnivorous',
    'optimal',
    'optimistic',
    'otherworldly',
    'outgoing',
    'outspoken',
    'panoramic',
    'peaceful',
    'perceptive',
    'perpetual',
    'perplexing',
    'perspicacious',
    'philosophical',
    'picturesque',
    'playful',
    'pleasant',
    'poised',
    'practical',
    'precious',
    'precise',
    'precocious',
    'prestigious',
    'primeval',
    'primordial',
    'prismatic',
    'proactive',
    'proficient',
    'prototypical',
    'prudent',
    'purposeful',
    'qualified',
    'quizzical',
    'quotable',
    'radiant',
    'reassured',
    'reclusive',
    'recursive',
    'recurring',
    'reflective',
    'rejoicing',
    'relaxed',
    'relieved',
    'remarkable',
    'renowned',
    'resilient',
    'resolute',
    'resourceful',
    'rigorous',
    'roaring',
    'robust',
    'salient',
    'salubrious',
    'sanguine',
    'sapient',
    'sarcastic',
    'satisfied',
    'scholarly',
    'scintillating',
    'scrupulous',
    'selective',
    'shiny',
    'sincere',
    'singing',
    'sleek',
    'sleepy',
    'slippery',
    'smiling',
    'smooth',
    'solid',
    'sophisticated',
    'sparkling',
    'spectacular',
    'splendid',
    'spotless',
    'squeaky',
    'stately',
    'steady',
    'strategic',
    'striped',
    'stunning',
    'stupendous',
    'stylish',
    'substantial',
    'sufficient',
    'swimming',
    'symbolic',
    'symmetrical',
    'taciturn',
    'terrestrial',
    'tessellated',
    'thankful',
    'theoretical',
    'thoughtful',
    'thriving',
    'timeless',
    'timely',
    'topographical',
    'transparent',
    'tranquil',
    'transparent',
    'tricky',
    'ubiquitous',
    'uncanny',
    'unclouded',
    'undisputed',
    'unexpected',
    'unfathomable',
    'unflappable',
    'unique',
    'universal',
    'unofficial',
    'unseen',
    'unthinkable',
    'uproarious',
    'variegated',
    'versatile',
    'victorious',
    'vigilant',
    'vigorous',
    'virtuous',
    'vivacious',
    'vivid',
    'vociferous',
    'wacky',
    'wandering',
    'watchful',
    'whimsical',
    'windswept',
    'witty',
    'wonderful',
    'wondrous',
    'yakkety',
    'yawning',
    'yeatsian',
    'yelling',
    'yellow',
    'yellowing',
    'young',
    'youthful',
    'yummy',
    'zany',
    'zaftig',
    'zealous',
    'zestful',
    'zesty',
    'zippy',
    'zoonatic',
    'zygomorphous',
    'zymoid',
    'zymolytic',
]
ANIMALS = [
    'aardvark',
    'albatross',
    'alligator',
    'alpaca',
    'angelfish',
    'anteater',
    'antelope',
    'ape',
    'armadillo',
    'badger',
    'barracuda',
    'bat',
    'beagle',
    'bear',
    'beaver',
    'bird',
    'bittern',
    'bobolink',
    'brontosaurus',
    'boa-constrictor',
    'buffalo',
    'bulldog',
    'bumblebee',
    'butterfly',
    'buzzard',
    'camel',
    'caribou',
    'cassowary',
    'cat',
    'catfish',
    'caterpillar',
    'cauldron',
    'centipede',
    'cete',
    'chameleon',
    'cheetah',
    'chinchilla',
    'chipmunk',
    'cobra',
    'coelacanth',
    'condor',
    'coot',
    'coral-snake',
    'cormorant',
    'crab',
    'crane',
    'crocodile',
    'dalmatian',
    'deer',
    'dolphin',
    'donkey',
    'dotterel',
    'dove',
    'dragonfish',
    'dragonfly',
    'duck',
    'eagle',
    'eel',
    'elephant',
    'elk',
    'falcon',
    'ferret',
    'finch',
    'firefly',
    'fish',
    'flamingo',
    'fox',
    'frog',
    'gang',
    'gazelle',
    'gecko',
    'gerbil',
    'giraffe',
    'gnu',
    'goldfish',
    'goose',
    'gorilla',
    'grasshopper',
    'greyhound',
    'grouse',
    'gull',
    'hamster',
    'hare',
    'hawk',
    'hatchetfish',
    'hedgehog',
    'heron',
    'herring',
    'hornet',
    'horse',
    'hummingbird',
    'ibex',
    'ibis',
    'iguana',
    'jackal',
    'jaguar',
    'jay',
    'jellyfish',
    'kangaroo',
    'kestrel',
    'kingfisher',
    'koala',
    'koi',
    'lapwing',
    'lark',
    'lemur',
    'leopard',
    'lion',
    'lionfish',
    'llama',
    'lobster',
    'loris',
    'magpie',
    'mallard',
    'mandrill',
    'manta-ray',
    'mantis',
    'marlin',
    'mastiff',
    'mollusk',
    'mongoose',
    'moose',
    'mouse',
    'mule',
    'narwhal',
    'nautilus',
    'newt',
    'nightingale',
    'obstinacy',
    'octopus',
    'okapi',
    'opossum',
    'orca',
    'osprey',
    'ostrich',
    'otter',
    'owl',
    'panda',
    'panther',
    'parrot',
    'partridge',
    'pelican',
    'penguin',
    'pheasant',
    'pig',
    'pigeon',
    'platypus',
    'polar-bear',
    'porcupine',
    'porpoise',
    'python',
    'quail',
    'rabbit',
    'raccoon',
    'ram',
    'raven',
    'reindeer',
    'rhinoceros',
    'roadrunner',
    'rook',
    'salamander',
    'salmon',
    'sandpiper',
    'scorpion',
    'sea-cucumber',
    'sea-lion',
    'sea-snake',
    'sea-turtle',
    'seahorse',
    'seal',
    'shark',
    'sheep',
    'shrewdness',
    'sloth',
    'sleuth',
    'snowy-owl',
    'songbird',
    'sparrow',
    'spider',
    'squid',
    'squirrel',
    'starfish',
    'starling',
    'stegosaurus',
    'stingray',
    'stork',
    'swan',
    'tapir',
    'tiger',
    'toucan',
    'triceratops',
    'turtle',
    'vampire-bat',
    'velociraptor',
    'wallaby',
    'water-buffalo',
    'walrus',
    'whale',
    'wolf',
    'wolverine',
    'wombat',
    'wrasse',
    'wren',
    'xantus',
    'xenarthra',
    'xenops',
    'xerus',
    'yabby',
    'yak',
    'yellow-eyed-penguin',
    'yellow-ground-squirrel',
    'yellow-mongoose',
    'yuma-myotis',
    'zebra',
    'zebra-finch',
    'zebrafish',
    'zebra-shark',
    'zebroid',
    'zebu',
    'zonkey',
    'zorilla',
    'zorro',
    'zorse',
    'clowder',      # cats
    'pounce',       # cats
    'kindle',       # kittens
    'litter',       # kittens, dogs
    'intrigue',     # kittens
    'cowardice',    # dogs
    'pace',         # donkeys
    'parade',       # elephants
    'business',     # ferrets
    'shrewdness',   # apes
    'gang',         # buffalo
    'obstinacy',    # buffalo
    'leash',        # foxes
    'skulk',        # foxes
    'earth',        # foxes
    'tower',        # giraffes
    'tribe',        # goats
    'trip',         # goats
    'band',         # gorillas
    'bloat',        # hippos
    'thunder',      # hippos
    'cackle',       # hyenas
    'shadow',       # jaguar
    'troop',        # kangaroo
    'mob',          # kangaroo
    'conspiracy',   # lemurs
    'leap',         # leopards
    'pride',        # lions
    'sawt',         # lions
    'richness',     # martens
    'labor',        # moles
    'troop',        # monkeys
    'barrel',       # monkeys
    'pack',         # mules
    'span',         # mules
    'barren',       # mules
    'romp',         # otter
    'drift',        # pigs
    'drove',        # drove
    'sounder',      # pigs
    'team',         # pigs
    'passel',       # pigs
    'prickle',      # porcupines
    'pod',          # porpoises, whales
    'school',       # porpoises, whales
    'herd',         # porpoises
    'turmoil',      # porpoises
    'colony',       # rabbits
    'warren',       # rabbits
    'nest',         # rabbits
    'down',         # rabbits
    'husk',         # rabbits
    'gam',          # whales
    'route',        # wolves
    'woute',        # wolves
    'sedge',        # bitterns
    'wake',         # buzzard
    'chain',        # bobolink
    'cover',        # coot
    'gulp',         # cormorants
    'murder',       # crows, magpies
    'horde',        # crows
    'trip',         # dotterel
    'dule',         # doves
    'pitying',      # doves
    'brace',        # ducks
    'team',         # ducks
    'flock',        # ducks
    'raft',         # ducks
    'paddling',     # ducks
    'badling',      # ducks
    'convocation',  # eagles
    'charm',        # finches, magpies
    'flamingos',    # stand
    'gaggle',       # geese
    'skein',        # geese
    'cast',         # hawk
    'kettle',       # hawk
    'boil',         # hawk
    'sedge',        # heron
    'siege',        # heron
    'party',        # jays
    'scold',        # jays
    'deceit',       # lapwings
    'exaltation',   # larks
    'sord',         # mallards
    'tiding',       # magpies
    'gulp',         # magpies
    'watch',        # nightingales
    'parliament',   # owls
    'pandemonium',  # parrots
    'company',      # parrots
    'covey',        # partridge
    'ostentation',  # peacocks
    'muster',       # peacocks, penguins
    'parcel',       # penguins
    'rookery',      # rookery
]

